@@ -9,9 +9,9 @@ use Complete::Common qw(:all);
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-01'; # DATE
+our $DATE = '2023-12-26'; # DATE
 our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.618'; # VERSION
+our $VERSION = '0.619'; # VERSION
 
 our @EXPORT_OK = qw(
                        hashify_answer
@@ -26,6 +26,8 @@ our @EXPORT_OK = qw(
                        complete_hash_value
                        complete_comma_sep
                        complete_comma_sep_pair
+                       get_answer_words
+                       get_answer_summaries
                );
 
 our %SPEC;
@@ -133,6 +135,70 @@ sub arrayify_answer {
     $ans;
 }
 
+$SPEC{get_answer_words} = {
+    v => 1.1,
+    summary => 'Extract just the words from answer structure',
+    description => <<'_',
+
+This routine accepts a hash or an array answer structure. It then returns an
+arrayref containing just the words from each answer entry. If the answer is
+undef, it returns an empty arrayref.
+
+See also: `get_answer_summaries()`.
+
+_
+    args => {
+        %arg0_answer,
+    },
+    args_as => 'array',
+    result_naked => 1,
+    result => {
+        schema => 'array*',
+    },
+};
+sub get_answer_words {
+    my $ans = shift;
+    return [] unless defined $ans;
+    if (ref($ans) eq 'HASH') {
+        $ans = $ans->{words};
+    }
+    my @words;
+    for (@$ans) { push @words, ref($_) eq 'HASH' ? $_->{word} : $_ }
+    \@words;
+}
+
+$SPEC{get_answer_summaries} = {
+    v => 1.1,
+    summary => 'Extract just the entry summaries from answer structure',
+    description => <<'_',
+
+This routine accepts a hash or an array answer structure. It then returns an
+arrayref containing just the summaries from each answer entry. If the answer is
+undef, it returns an empty arrayref.
+
+See also: `get_answer_words()`.
+
+_
+    args => {
+        %arg0_answer,
+    },
+    args_as => 'array',
+    result_naked => 1,
+    result => {
+        schema => 'array*',
+    },
+};
+sub get_answer_summaries {
+    my $ans = shift;
+    return [] unless defined $ans;
+    if (ref($ans) eq 'HASH') {
+        $ans = $ans->{words};
+    }
+    my @summaries;
+    for (@$ans) { push @summaries, ref($_) eq 'HASH' ? $_->{summary} : undef }
+    \@summaries;
+}
+
 $SPEC{answer_num_entries} = {
     v => 1.1,
     summary => 'Get the number of entries in an answer',
@@ -1154,7 +1220,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.618 of Complete::Util (from Perl distribution Complete-Util), released on 2023-12-01.
+This document describes version 0.619 of Complete::Util (from Perl distribution Complete-Util), released on 2023-12-26.
 
 =head1 DESCRIPTION
 
@@ -1638,6 +1704,68 @@ Return value:  (array)
 
 
 
+=head2 get_answer_summaries
+
+Usage:
+
+ get_answer_summaries($answer) -> array
+
+Extract just the entry summaries from answer structure.
+
+This routine accepts a hash or an array answer structure. It then returns an
+arrayref containing just the summaries from each answer entry. If the answer is
+undef, it returns an empty arrayref.
+
+See also: C<get_answer_words()>.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<$answer>* => I<array|hash>
+
+Completion answer structure.
+
+
+=back
+
+Return value:  (array)
+
+
+
+=head2 get_answer_words
+
+Usage:
+
+ get_answer_words($answer) -> array
+
+Extract just the words from answer structure.
+
+This routine accepts a hash or an array answer structure. It then returns an
+arrayref containing just the words from each answer entry. If the answer is
+undef, it returns an empty arrayref.
+
+See also: C<get_answer_summaries()>.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<$answer>* => I<array|hash>
+
+Completion answer structure.
+
+
+=back
+
+Return value:  (array)
+
+
+
 =head2 hashify_answer
 
 Usage:
